;; Generated package description from yasnippet.el  -*- no-byte-compile: t -*-
(define-package "yasnippet" "0.14.2.0.20250601.184313" "Yet another snippet extension for Emacs" '((cl-lib "0.5") (emacs "24.4")) :commit "272b6067f17675eb4eb001a7a933a52e730152cf" :maintainer '("Noam Postavsky" . "npostavs@gmail.com") :keywords '("convenience" "emulation") :url "http://github.com/joaotavora/yasnippet")
